===================================================
django-content-editor -- Editing structured content
===================================================

`Documentation on Read the Docs <http://django-content-editor.readthedocs.org/en/latest/>`_

.. image:: https://travis-ci.org/matthiask/django-content-editor.svg?branch=master
    :target: https://travis-ci.org/matthiask/django-content-editor

.. image:: https://readthedocs.org/projects/django-content-editor/badge/?version=latest
    :target: https://django-content-editor.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
